@@ -398,6 +398,7 @@ thunar_chooser_dialog_response (GtkDialog *widget,
   GList                list;
   GList               *all_apps, *lp;
   GdkScreen           *screen;
+  GAppInfo            *default_app = NULL;
 
   /* no special processing for non-accept responses */
   if (G_UNLIKELY (response != GTK_RESPONSE_ACCEPT))
@@ -457,8 +458,12 @@ thunar_chooser_dialog_response (GtkDialog *widget,
   if (G_UNLIKELY (app_info == NULL))
     return;
 
-  /* check if we should also set the application as default */
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->default_button)))
+  default_app = g_app_info_get_default_for_type (content_type, FALSE);
+
+  /* check if we should also set the application as default or
+   * if application is opened first time, set it as default application */
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->default_button))
+      || default_app == NULL)
     {
       /* remember the application as default for these kind of file */
       succeed = g_app_info_set_as_default_for_type (app_info, content_type, &error);
@@ -490,6 +495,9 @@ thunar_chooser_dialog_response (GtkDialog *widget,
         }
     }
 
+  if (default_app != NULL)
+    g_object_unref (default_app);
+
   /* check if we should also execute the application */
   if (G_LIKELY (succeed && dialog->open))
     {
@@ -1017,7 +1025,7 @@ thunar_chooser_dialog_expand (ThunarChooserDialog *dialog)
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->tree_view));
 
-  /* expand the first tree view row (the recommended applications) */
+  /* expand the first tree view row (the default application) */
   if (G_LIKELY (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter)))
     {
       path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
@@ -1025,7 +1033,15 @@ thunar_chooser_dialog_expand (ThunarChooserDialog *dialog)
       gtk_tree_path_free (path);
     }
 
-  /* expand the second tree view row (the other applications) */
+  /* expand the second tree view row (the recommended applications) */
+  if (G_LIKELY (gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter)))
+    {
+      path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
+      gtk_tree_view_expand_to_path (GTK_TREE_VIEW (dialog->tree_view), path);
+      gtk_tree_path_free (path);
+    }
+
+  /* expand the third tree view row (the other applications) */
   if (G_LIKELY (gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter)))
     {
       path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
@@ -1258,11 +1274,13 @@ thunar_chooser_dialog_set_open (ThunarChooserDialog *dialog,
 
 /**
  * thunar_show_chooser_dialog:
- * @parent : the #GtkWidget or the #GdkScreen on which to open the
- *           dialog. May also be %NULL in which case the default
- *           #GdkScreen will be used.
- * @file   : the #ThunarFile for which an application should be chosen.
- * @open   : whether to also open the @file.
+ * @parent                      : the #GtkWidget or the #GdkScreen on which to open the
+ *                                dialog. May also be %NULL in which case the default
+ *                                #GdkScreen will be used.
+ * @file                        : the #ThunarFile for which an application should be chosen.
+ * @open                        : whether to also open the @file.
+ * @preselect_default_checkbox  : Check the checkbox by default and
+ *                                set the title "Set Default Application" of chooser dialog box.
  *
  * Convenience function to display a #ThunarChooserDialog with the
  * given parameters.
@@ -1275,7 +1293,8 @@ thunar_chooser_dialog_set_open (ThunarChooserDialog *dialog,
 void
 thunar_show_chooser_dialog (gpointer    parent,
                             ThunarFile *file,
-                            gboolean    open)
+                            gboolean    open,
+                            gboolean    preselect_default_checkbox)
 {
   ThunarApplication *application;
   GdkScreen         *screen;
@@ -1310,6 +1329,13 @@ thunar_show_chooser_dialog (gpointer    parent,
                          "screen", screen,
                          NULL);
 
+  /* change title of chooser dialog box and checked the checkbox when it is used for select default application */
+  if (preselect_default_checkbox)
+  {
+    gtk_window_set_title (GTK_WINDOW (dialog), _("Set Default Application"));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (THUNAR_CHOOSER_DIALOG (dialog)->default_button), preselect_default_checkbox);
+  }
+
   /* check if we have a toplevel window */
   if (G_LIKELY (window != NULL && gtk_widget_get_toplevel (window)))
     {
