@@ -66,6 +66,7 @@ typedef enum
   THUNAR_DATE_STYLE_MMDDYYYY,
   THUNAR_DATE_STYLE_DDMMYYYY,
   THUNAR_DATE_STYLE_CUSTOM,
+  THUNAR_DATE_STYLE_CUSTOM_SIMPLE,
 } ThunarDateStyle;
 
 GType thunar_date_style_get_type (void) G_GNUC_CONST;
@@ -78,6 +79,7 @@ GType thunar_date_style_get_type (void) G_GNUC_CONST;
  * @THUNAR_COLUMN_DATE_CREATED  : created time.
  * @THUNAR_COLUMN_DATE_ACCESSED : last access time.
  * @THUNAR_COLUMN_DATE_MODIFIED : last modification time.
+ * @THUNAR_COLUMN_DATE_DELETED  : deletion time.
  * @THUNAR_COLUMN_GROUP         : group's name.
  * @THUNAR_COLUMN_MIME_TYPE     : mime type (e.g. "text/plain").
  * @THUNAR_COLUMN_NAME          : display name.
@@ -98,6 +100,7 @@ typedef enum
   THUNAR_COLUMN_DATE_CREATED,
   THUNAR_COLUMN_DATE_ACCESSED,
   THUNAR_COLUMN_DATE_MODIFIED,
+  THUNAR_COLUMN_DATE_DELETED,
   THUNAR_COLUMN_GROUP,
   THUNAR_COLUMN_MIME_TYPE,
   THUNAR_COLUMN_NAME,
