@@ -66,10 +66,6 @@ static gboolean    thunar_location_entry_button_press_event       (GtkWidget
                                                                    GdkEventButton           *event,
                                                                    ThunarLocationEntry      *location_entry);
 static gboolean    thunar_location_entry_reset                    (ThunarLocationEntry      *location_entry);
-static void        thunar_location_entry_reload                   (GtkEntry                 *entry,
-                                                                   GtkEntryIconPosition      icon_pos,
-                                                                   GdkEvent                 *event,
-                                                                   ThunarLocationEntry      *location_entry);
 static void        thunar_location_entry_emit_edit_done           (ThunarLocationEntry      *entry);
 
 
@@ -136,19 +132,7 @@ thunar_location_entry_class_init (ThunarLocationEntryClass *klass)
                 _thunar_marshal_BOOLEAN__VOID,
                 G_TYPE_BOOLEAN, 0);
 
-  /**
-   * ThunarLocationEntry::reload-requested:
-   * @location_entry : a #ThunarLocationEntry.
-   *
-   * Emitted by @location_entry whenever the user clicked a "reload" button
-   **/
-  g_signal_new ("reload-requested",
-                G_TYPE_FROM_CLASS (klass),
-                G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-                G_STRUCT_OFFSET (ThunarLocationEntryClass, reload_requested),
-                NULL, NULL,
-                NULL,
-                G_TYPE_NONE, 0);
+
 
   /**
    * ThunarLocationEntry::edit-done:
@@ -193,14 +177,6 @@ thunar_location_entry_init (ThunarLocationEntry *location_entry)
   gtk_box_pack_start (GTK_BOX (location_entry), location_entry->path_entry, TRUE, TRUE, 0);
   gtk_widget_show (location_entry->path_entry);
 
-  /* put reload button in entry */
-  gtk_entry_set_icon_from_icon_name (GTK_ENTRY (location_entry->path_entry),
-                                     GTK_ENTRY_ICON_SECONDARY, "view-refresh-symbolic");
-  gtk_entry_set_icon_tooltip_text (GTK_ENTRY (location_entry->path_entry),
-                                   GTK_ENTRY_ICON_SECONDARY, _("Reload the current folder"));
-  g_signal_connect (G_OBJECT (location_entry->path_entry), "icon-release",
-                    G_CALLBACK (thunar_location_entry_reload), location_entry);
-
   /* make sure the edit-done signal is emitted upon moving the focus somewhere else */
   g_signal_connect_swapped (location_entry->path_entry, "focus-out-event", G_CALLBACK (thunar_location_entry_emit_edit_done), location_entry);
 
@@ -454,22 +430,6 @@ thunar_location_entry_reset (ThunarLocationEntry *location_entry)
 
 
 
-static void
-thunar_location_entry_reload (GtkEntry            *entry,
-                              GtkEntryIconPosition icon_pos,
-                              GdkEvent            *event,
-                              ThunarLocationEntry *location_entry)
-{
-  _thunar_return_if_fail (THUNAR_IS_LOCATION_ENTRY (location_entry));
-
-  if (icon_pos == GTK_ENTRY_ICON_SECONDARY)
-    {
-      g_signal_emit_by_name (location_entry, "reload-requested");
-    }
-}
-
-
-
 static void
 thunar_location_entry_emit_edit_done (ThunarLocationEntry *entry)
 {
