@@ -170,12 +170,14 @@ struct _ThunarRenamerDialog
   GtkWidget           *tree_view;
   GtkWidget           *progress;
 
+  GtkWidget           *mode_combo;
+
   GtkTreeViewColumn   *name_column;
 
   /* the current directory used for the "Add Files" dialog */
   ThunarFile          *current_directory;
 
-  /* the list of currently selected files */
+  /* #GList of currently selected #ThunarFile<!---->s */
   GList               *selected_files;
 
   /* whether the dialog should act like a standalone application */
@@ -358,15 +360,22 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   renamer_dialog->close_button = gtk_dialog_add_button (GTK_DIALOG (renamer_dialog), _("_Close"), GTK_RESPONSE_DELETE_EVENT);
   gtk_widget_hide (renamer_dialog->close_button);
 
-  /* add the "Rename Files" button */
-  button = gtk_dialog_add_button (GTK_DIALOG (renamer_dialog), _("_Rename Files"), GTK_RESPONSE_ACCEPT);
+  /* add the "Done" button */
+  button = gtk_dialog_add_button (GTK_DIALOG (renamer_dialog), _("_Done"), GTK_RESPONSE_ACCEPT);
   exo_binding_new (G_OBJECT (renamer_dialog->model), "can-rename", G_OBJECT (button), "sensitive");
   gtk_dialog_set_default_response (GTK_DIALOG (renamer_dialog), GTK_RESPONSE_ACCEPT);
-  gtk_widget_set_tooltip_text (button, _("Click here to actually rename the files listed above to their new names."));
+  gtk_widget_set_tooltip_text (button, _("Click here to actually rename the files listed above to their new names and close the window."));
+
+  /* add the "Apply" button */
+  button = gtk_dialog_add_button (GTK_DIALOG (renamer_dialog), _("_Apply"), GTK_RESPONSE_APPLY);
+  exo_binding_new (G_OBJECT (renamer_dialog->model), "can-rename", G_OBJECT (button), "sensitive");
+  gtk_dialog_set_default_response (GTK_DIALOG (renamer_dialog), GTK_RESPONSE_APPLY);
+  gtk_widget_set_tooltip_text (button, _("Click here to actually rename the files listed above to their new names and keep the window open."));
 
   /* setup the launcher support for this dialog */
   renamer_dialog->launcher = g_object_new (THUNAR_TYPE_LAUNCHER, "widget", GTK_WIDGET (renamer_dialog), NULL);
   exo_binding_new (G_OBJECT (renamer_dialog), "selected-files", G_OBJECT (renamer_dialog->launcher), "selected-files");
+  exo_binding_new (G_OBJECT (renamer_dialog), "current-directory", G_OBJECT (renamer_dialog->launcher), "current-directory");
 
   /* add the toolbar to the dialog */
   toolbar = gtk_toolbar_new ();
@@ -475,6 +484,8 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
   gtk_widget_show (frame);
 
+  renamer_dialog->mode_combo = NULL;
+
   /* check if we have any renamers */
   if (G_LIKELY (renamers != NULL))
     {
@@ -518,6 +529,7 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
       gtk_combo_box_set_active (GTK_COMBO_BOX (mcombo), active);
       g_type_class_unref (klass);
       gtk_widget_show (mcombo);
+      renamer_dialog->mode_combo = mcombo;
 
       /* allocate the notebook with the renamers */
       notebook = gtk_notebook_new ();
@@ -752,7 +764,7 @@ thunar_renamer_dialog_response (GtkDialog *dialog,
   g_object_ref (G_OBJECT (dialog));
 
   /* check if we should rename */
-  if (G_LIKELY (response == GTK_RESPONSE_ACCEPT))
+  if (G_LIKELY (response == GTK_RESPONSE_ACCEPT  || response == GTK_RESPONSE_APPLY))
     {
       /* hide the close button and show the cancel button */
       gtk_widget_show (renamer_dialog->cancel_button);
@@ -797,7 +809,7 @@ thunar_renamer_dialog_response (GtkDialog *dialog,
       thunar_renamer_pair_list_free (pair_list);
 
       /* check if we're in standalone mode */
-      if (thunar_renamer_dialog_get_standalone (renamer_dialog))
+      if (thunar_renamer_dialog_get_standalone (renamer_dialog) || response == GTK_RESPONSE_APPLY)
         {
           /* hide the cancel button again and display the close button */
           gtk_widget_hide (renamer_dialog->cancel_button);
@@ -882,19 +894,14 @@ thunar_renamer_dialog_context_menu (ThunarRenamerDialog *renamer_dialog)
   /* grab an additional reference on the dialog */
   g_object_ref (G_OBJECT (renamer_dialog));
 
-  /* determine the active renamer */
-  renamer = thunar_renamer_model_get_renamer (renamer_dialog->model);
-  if (G_LIKELY (renamer != NULL))
-    {
-      /* determine the menu items provided by the active renamer */
-      items = thunarx_renamer_get_menu_items (renamer, GTK_WINDOW (renamer_dialog), renamer_dialog->selected_files);
-    }
-
   menu = g_object_new (THUNAR_TYPE_MENU, "menu-type", THUNAR_MENU_TYPE_CONTEXT_RENAMER,
                                          "launcher", renamer_dialog->launcher,
                                          "tab-support-disabled", TRUE,
                                          "change_directory-support-disabled", TRUE, NULL);
   thunar_menu_add_sections (menu, THUNAR_MENU_SECTION_OPEN | THUNAR_MENU_SECTION_SENDTO);
+
+  /* determine the active renamer */
+  renamer = thunar_renamer_model_get_renamer (renamer_dialog->model);
   if (G_LIKELY (renamer != NULL))
     {
       /* determine the menu items provided by the active renamer */
@@ -1833,7 +1840,9 @@ thunar_show_renamer_dialog (gpointer     parent,
   GdkScreen         *screen;
   GtkWidget         *dialog;
   GtkWidget         *window = NULL;
+  GtkComboBox       *mode_combo;
   GList             *lp;
+  gboolean           directories_only;
 
   _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
 
@@ -1878,6 +1887,16 @@ thunar_show_renamer_dialog (gpointer     parent,
   for (lp = files; lp != NULL; lp = lp->next)
     thunar_renamer_model_append (THUNAR_RENAMER_DIALOG (dialog)->model, lp->data);
 
+  /* if there are only directories selected change the mode to both */
+  directories_only = TRUE;
+  for (lp = files; lp != NULL; lp = lp->next)
+    if (thunar_file_is_directory (THUNAR_FILE (lp->data)) == FALSE)
+      directories_only = FALSE;
+
+  mode_combo = GTK_COMBO_BOX (THUNAR_RENAMER_DIALOG (dialog)->mode_combo);
+  if (directories_only && mode_combo != NULL)
+    gtk_combo_box_set_active (mode_combo, THUNAR_RENAMER_MODE_BOTH);
+
   /* let the application handle the dialog */
   application = thunar_application_get ();
   thunar_application_take_window (application, GTK_WINDOW (dialog));
