@@ -64,14 +64,6 @@ enum
   TEXT_URI_LIST,
 };
 
-/* Target for open action */
-typedef enum
-{
-  OPEN_IN_VIEW,
-  OPEN_IN_WINDOW,
-  OPEN_IN_TAB
-}
-OpenTarget;
 
 
 static void           thunar_shortcuts_view_navigator_init               (ThunarNavigatorIface     *iface);
@@ -154,17 +146,17 @@ static GtkTreePath   *thunar_shortcuts_view_compute_drop_position        (Thunar
 static void           thunar_shortcuts_view_drop_uri_list                (ThunarShortcutsView      *view,
                                                                           GList                    *path_list,
                                                                           GtkTreePath              *dst_path);
-static void           thunar_shortcuts_view_open                         (ThunarShortcutsView      *view,
-                                                                          OpenTarget                open_in);
-static void           thunar_shortcuts_view_eject                        (ThunarShortcutsView      *view);
-static void           thunar_shortcuts_view_stop_spinner                 (ThunarShortcutsView      *view,
-                                                                          ThunarDevice             *device,
-                                                                          gpointer                  user_data);
-static void           thunar_shortcuts_view_start_spinner                (ThunarShortcutsView      *view,
-                                                                          ThunarDevice             *device,
-                                                                          gpointer                  user_data);
-static void           thunar_shortcuts_view_new_files_created            (ThunarShortcutsView      *view,
-                                                                          GList                    *files_to_selected);
+static void           thunar_shortcuts_view_open                         (ThunarShortcutsView           *view,
+                                                                          ThunarLauncherFolderOpenAction open_in);
+static void           thunar_shortcuts_view_eject                        (ThunarShortcutsView           *view);
+static void           thunar_shortcuts_view_stop_spinner                 (ThunarShortcutsView           *view,
+                                                                          ThunarDevice                  *device,
+                                                                          gpointer                       user_data);
+static void           thunar_shortcuts_view_start_spinner                (ThunarShortcutsView           *view,
+                                                                          ThunarDevice                  *device,
+                                                                          gpointer                       user_data);
+static void           thunar_shortcuts_view_new_files_created            (ThunarShortcutsView           *view,
+                                                                          GList                         *files_to_selected);
 
 
 
@@ -425,7 +417,7 @@ thunar_shortcuts_view_finalize (GObject *object)
   ThunarShortcutsView *view = THUNAR_SHORTCUTS_VIEW (object);
 
   /* release drop path list (if drag_leave wasn't called) */
-  thunar_g_file_list_free (view->drop_file_list);
+  thunar_g_list_free_full (view->drop_file_list);
 
   /* release the provider factory */
   g_object_unref (G_OBJECT (view->provider_factory));
@@ -630,7 +622,7 @@ thunar_shortcuts_view_button_release_event (GtkWidget      *widget,
       else if (G_LIKELY (event->button == 1))
         {
           /* button 1 opens in the same window */
-          thunar_shortcuts_view_open (view, OPEN_IN_VIEW);
+          thunar_shortcuts_view_open (view, THUNAR_LAUNCHER_CHANGE_DIRECTORY);
         }
       else if (G_UNLIKELY (event->button == 2))
         {
@@ -641,7 +633,7 @@ thunar_shortcuts_view_button_release_event (GtkWidget      *widget,
           if ((event->state & GDK_CONTROL_MASK) != 0)
             in_tab = !in_tab;
 
-          thunar_shortcuts_view_open (view, in_tab ? OPEN_IN_TAB : OPEN_IN_WINDOW);
+          thunar_shortcuts_view_open (view, in_tab ? THUNAR_LAUNCHER_OPEN_AS_NEW_TAB : THUNAR_LAUNCHER_OPEN_AS_NEW_WINDOW);
         }
     }
 
@@ -668,7 +660,7 @@ thunar_shortcuts_view_key_release_event (GtkWidget   *widget,
     case GDK_KEY_Down:
     case GDK_KEY_KP_Up:
     case GDK_KEY_KP_Down:
-      thunar_shortcuts_view_open (view, OPEN_IN_VIEW);
+      thunar_shortcuts_view_open (view, THUNAR_LAUNCHER_CHANGE_DIRECTORY);
 
       /* keep focus on us */
       gtk_widget_grab_focus (widget);
@@ -990,7 +982,7 @@ thunar_shortcuts_view_drag_leave (GtkWidget      *widget,
   /* reset the "drop data ready" status and free the URI list */
   if (G_LIKELY (view->drop_data_ready))
     {
-      thunar_g_file_list_free (view->drop_file_list);
+      thunar_g_list_free_full (view->drop_file_list);
       view->drop_data_ready = FALSE;
       view->drop_file_list = NULL;
     }
@@ -1047,7 +1039,7 @@ thunar_shortcuts_view_row_activated (GtkTreeView       *tree_view,
     (*GTK_TREE_VIEW_CLASS (thunar_shortcuts_view_parent_class)->row_activated) (tree_view, path, column);
 
   /* open the selected shortcut */
-  thunar_shortcuts_view_open (view, OPEN_IN_VIEW);
+  thunar_shortcuts_view_open (view, THUNAR_LAUNCHER_CHANGE_DIRECTORY);
 }
 
 
@@ -1225,7 +1217,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
   if (location != NULL && file == NULL)
     {
       file = thunar_file_get (location, NULL);
-      if (thunar_file_exists (file) == FALSE)
+      if (file != NULL && thunar_file_exists (file) == FALSE)
         {
           g_object_unref (G_OBJECT (file));
           file = NULL;
@@ -1658,14 +1650,16 @@ thunar_shortcuts_view_drop_uri_list (ThunarShortcutsView *view,
 
 
 static void
-thunar_shortcuts_view_open (ThunarShortcutsView *view,
-                            OpenTarget           open_in)
+thunar_shortcuts_view_open (ThunarShortcutsView            *view,
+                            ThunarLauncherFolderOpenAction  open_in)
 {
   GtkTreeSelection *selection;
   GtkTreeModel     *model;
   GtkTreeIter       iter;
+  GtkTreeIter       iterator;
+  gboolean          hasShortcut;
   ThunarFile       *file;
-  GList *files;
+  GList            *files;
   ThunarDevice     *device;
   GFile            *location;
 
@@ -1702,7 +1696,25 @@ thunar_shortcuts_view_open (ThunarShortcutsView *view,
            g_object_set (G_OBJECT (view->launcher), "selected-location", location, NULL);
          }
 
-      thunar_launcher_activate_selected_files (view->launcher, THUNAR_LAUNCHER_CHANGE_DIRECTORY, NULL);
+      thunar_launcher_activate_selected_files (view->launcher, (ThunarLauncherFolderOpenAction) open_in, NULL);
+
+      /* select the correct bookmark/shortcut when opening in a new window */
+      model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model)); /* model is no longer a GtkTreeModelFilter */
+      hasShortcut = thunar_shortcuts_model_iter_for_file (THUNAR_SHORTCUTS_MODEL (model), view->current_directory, &iterator);
+      if (hasShortcut == FALSE) /* no bookmark selected */
+        gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (view)));
+      else                      /* select the correct bookmark */
+        {
+          GtkTreeViewColumn *column = NULL;
+          GtkTreePath       *l_path = NULL;
+
+          l_path = gtk_tree_model_get_path (model, &iterator);
+          column = gtk_tree_view_get_column (GTK_TREE_VIEW (view), 0);
+
+          gtk_tree_view_set_cursor (GTK_TREE_VIEW (view), l_path, column, FALSE);
+
+          gtk_tree_path_free (l_path);
+        }
 
       if (file != NULL)
         g_object_unref (file);
