@@ -203,7 +203,7 @@ thunar_transfer_job_finalize (GObject *object)
   if (job->target_device_fs_id != NULL)
     g_free (job->target_device_fs_id);
 
-  thunar_g_file_list_free (job->target_file_list);
+  thunar_g_list_free_full (job->target_file_list);
 
   g_object_unref (job->preferences);
 
@@ -384,7 +384,7 @@ thunar_transfer_job_collect_node (ThunarTransferJob  *job,
         }
 
       /* release the child files */
-      thunar_g_file_list_free (file_list);
+      thunar_g_list_free_full (file_list);
     }
 
   /* release file info */
@@ -779,7 +779,7 @@ retry_copy:
               if (G_LIKELY (target_file_list_return != NULL))
                 {
                   *target_file_list_return =
-                    thunar_g_file_list_prepend (*target_file_list_return,
+                    thunar_g_list_prepend_deep (*target_file_list_return,
                                                 real_target_file);
                 }
 
@@ -1133,7 +1133,7 @@ thunar_transfer_job_move_file (ExoJob                *job,
                                             tp->data);
 
           /* add the target file to the new files list */
-          *new_files_list_p = thunar_g_file_list_prepend (*new_files_list_p, tp->data);
+          *new_files_list_p = thunar_g_list_prepend_deep (*new_files_list_p, tp->data);
         }
 
       /* release source and target files */
@@ -1598,7 +1598,7 @@ thunar_transfer_job_execute (ExoJob  *job,
   else
     {
       thunar_job_new_files (THUNAR_JOB (job), new_files_list);
-      thunar_g_file_list_free (new_files_list);
+      thunar_g_list_free_full (new_files_list);
       return TRUE;
     }
 }
@@ -1670,7 +1670,7 @@ thunar_transfer_job_new (GList                *source_node_list,
           job->source_node_list = g_list_append (job->source_node_list, node);
 
           /* append target file */
-          job->target_file_list = thunar_g_file_list_append (job->target_file_list, tp->data);
+          job->target_file_list = thunar_g_list_append_deep (job->target_file_list, tp->data);
         }
     }
 
