@@ -117,6 +117,9 @@ void                      thunar_window_update_directories                  (Thu
                                                                              ThunarFile          *new_directory);
 void                      thunar_window_notebook_open_new_tab               (ThunarWindow        *window,
                                                                              ThunarFile          *directory);
+void                      thunar_window_notebook_add_new_tab                (ThunarWindow        *window,
+                                                                             ThunarFile          *directory,
+                                                                             gboolean             force_switch_to_new_tab);
 gboolean                  thunar_window_has_shortcut_sidepane               (ThunarWindow        *window);
 GtkWidget*                thunar_window_get_sidepane                        (ThunarWindow        *window);
 void                      thunar_window_append_menu_item                    (ThunarWindow        *window,
@@ -127,6 +130,8 @@ void                      thunar_window_redirect_menu_tooltips_to_statusbar (Thu
                                                                              GtkMenu             *menu);
 const XfceGtkActionEntry* thunar_window_get_action_entry                    (ThunarWindow        *window,
                                                                              ThunarWindowAction   action);
+ void                     thunar_window_select_files                        (ThunarWindow        *window,
+                                                                             GList               *files_to_select);
 G_END_DECLS;
 
 #endif /* !__THUNAR_WINDOW_H__ */
